"""LocationParser test

This file provides tests for a LocationParser.
"""

from bs4 import BeautifulSoup

from uppaal2jetracer.declarations.declarations_tree_visitor import DeclarationsTreeVisitor
from uppaal2jetracer.parser.parser import LocationParser
from uppaal2jetracer.uppaalmodel.elements import Location, Invariant

parser = LocationParser()
tree_visitor: DeclarationsTreeVisitor = DeclarationsTreeVisitor()


def test_parse_id():
    """
    Test that the location parser parses an id as expected.
    """

    location_tag = """\t\t<location id="id2" x="64" y="48">
\t\t\t<name x="54" y="18">A</name>
\t\t</location>
        """
    location = parser.parse(BeautifulSoup(location_tag, "lxml-xml").find("location"))
    assert isinstance(location, Location)
    assert location.identifier == "id2"


def test_parse_name():
    """
    Test that the location parser parses names as expected.
    """

    location_tag = """\t\t<location id="id1" x="216" y="48">
\t\t\t<name x="216" y="16">req</name>
\t\t\t<label kind="invariant" x="240" y="32">x<=k</label>
\t\t</location>
    """
    location = parser.parse(BeautifulSoup(location_tag, "lxml-xml").find("location"))
    assert isinstance(location, Location)
    assert location.name == "req"


def test_parse_invariant():
    """
    Test that the location parser parses invariants as expected.
    """

    location_tag = """\t\t<location id="id1" x="216" y="48">
\t\t\t<name x="216" y="16">req</name>
\t\t\t<label kind="invariant" x="240" y="32">x&lt;=k</label>
\t\t</location>
    """
    location = parser.parse(BeautifulSoup(location_tag, "lxml-xml").find("location"))
    assert isinstance(location.invariant, Invariant)
    assert ("(FileAST: "
            "(BinaryOp: ((ID: x)) <= ((ID: k)))"
            ")") == location.invariant.decision.accept(tree_visitor)
