/**
 * This file holds the event for stopping the controller if it is running.
 * 
 * @module scripts/events/main/stop
 */

import RequestHandler from "../../request_handler.js";
import PageHandler from "../../page_handler.js";
import EventHandler from "../../event_handler.js";

/**
 * Stops the controller and clears the console.
 * 
 * @function stop_event
 * 
 * @param {HTMLElement} target            - Is the targeted UI element that was clicked.
 * @param {object} args                   - The data attributes of the targeted element.
 * @param {RequestHandler} requestHandler - The handler for HTTP requests.
 * @param {PageHandler} pageHandler       - The handler for UI updates.
 * @param {EventHandler} eventHandler     - The handler for the events.
 */
function stop_event(target, args, requestHandler, pageHandler, eventHandler) {

    pageHandler.clearConsole();

    requestHandler.POST("/api/stop", [], {}, (res) => {

        if (res.type) {

            pageHandler.addError(res.message, false);

        } else {

            pageHandler.addError(res.error);

        }

        eventHandler.isHandlingEvent = false;

    });

}

export default stop_event;
